/***********************************************************************/
/*                                                                     */
/*  FILE        :Main.c or Main.cpp                                    */
/*  DATE        :Tue, Oct 31, 2006                                     */
/*  DESCRIPTION :Main Program                                          */
/*  CPU TYPE    :                                                      */
/*                                                                     */
/*  NOTE:THIS IS A TYPICAL EXAMPLE.                                    */
/*                                                                     */
/***********************************************************************/

/*******************************************************************************
Includes <System Includes> , "Project Includes"
*******************************************************************************/
//#include "typedefine.h"
#include "iodefine.h"
#include "stdbool.h"
#include "R_PG_RSPI_RX63N.h"
#include <string.h>

/*******************************************************************************
Macro definitions
*******************************************************************************/
#define BUFF_SIZE       (4)                         /* setting buffer size */

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
void main(void);

/*******************************************************************************
* Constant Definition
*******************************************************************************/
const uint32_t send_buf[BUFF_SIZE] =
{
    0x11, 0x22, 0x33, 0x44
};  /* send data from RSPI0 to RSPI1 */

/*******************************************************************************
* Private global variables and functions
*******************************************************************************/
uint32_t CH0_read_buf[BUFF_SIZE];                   /* read buffer for RSPI0 */
uint32_t CH1_read_buf[BUFF_SIZE];                   /* read buffer for RSPI1 */
uint32_t dummy_rcv[BUFF_SIZE];
uint32_t dummy_trs[BUFF_SIZE] = { 0x00, 0x00, 0x00, 0x00 };

bool rspi0_receive_flag;
bool rspi1_receive_flag;
bool over_run0, mode_fault0, parity_error0;
bool over_run1, mode_fault1, parity_error1;

/*******************************************************************************
* Function Name: main
* Description  : Main program
* Arguments    : none
* Return Value : none
*******************************************************************************/
void main(void)
{
    /* Receive data from RSPI0 */
    rspi1_receive_flag = true;
    R_PG_RSPI_StartTransfer_C1(dummy_trs, CH1_read_buf, 1);

    /* Send data to RSPI1 */
    rspi0_receive_flag = false;
    R_PG_RSPI_StartTransfer_C0((uint32_t *)send_buf, dummy_rcv, 1);

    while(1);
}

/*******************************************************************************
* Function Name: Spi0Intfunc
* Description  : Finish transfer(RSPI0)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Spi0IntFunc(void)
{
    /* RSPI0 is received ? */
    if ( true == rspi0_receive_flag )
    {
        /* send/receive OK ? */
        if ( 0 == strcmp((const char *)CH0_read_buf, (const char *)send_buf) )
        {
            R_PG_IO_PORT_Write_PD6(0);    /* Turn on LED1 */
        }
        else
        {
            /* Do nothing */
        }
    }
    else
    {
        /* Do nothing */
    }
}

/*******************************************************************************
* Function Name: Spi1Intfunc
* Description  : Finish transfer(RSPI1)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Spi1IntFunc(void)
{
    /* RSPI1 is received ? */
    if ( true == rspi1_receive_flag )
    {
	/* Send data to RSPI0 */
        rspi1_receive_flag = false;
        R_PG_RSPI_StartTransfer_C1(CH1_read_buf, dummy_rcv, 1);

        /* Receive data from RSPI1 */
        rspi0_receive_flag = true;
        R_PG_RSPI_StartTransfer_C0(dummy_trs, CH0_read_buf, 1);
    }
    else
    {
        /* Do nothing */
    }
}

/*******************************************************************************
* Function Name: Spi0ErIntFunc
* Description  : Detect error(RSPI0)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Spi0ErIntFunc(void)
{
    /* Get error flag and clear */
    R_PG_RSPI_GetError_C0(&over_run0, &mode_fault0, &parity_error0);

    /* added error function */
}

/*******************************************************************************
* Function Name: Spi1ErIntFunc
* Description  : Detect error(RSPI1)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Spi1ErIntFunc(void)
{
    /* Get error flag and clear */
    R_PG_RSPI_GetError_C1(&over_run1, &mode_fault1, &parity_error1);

    /* added error function */
}

/******************************************************************************
Option-Setting Memory
******************************************************************************/
#pragma address OFS1_REG = 0xFFFFFF88   /* OFS1 register */
const unsigned long OFS1_REG = 0xFFFFFFFF;

#pragma address OFS0_REG = 0xFFFFFF8C   /* OFS0 register */
const unsigned long OFS0_REG = 0xFFFFFFFF;
